// SAL_VERSION=4.1.2 XML_VERSION=5.1.0
module HVAC {
struct command_abort_e0b0394c {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	value; // @Metadata=(Units="unitless",Description="Not used")
	};
#pragma keylist command_abort_e0b0394c 
struct command_disable_38d0a147 {  // @Metadata=(Description="Transition from state Enabled to Disabled.")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	value; // @Metadata=(Units="unitless",Description="Not used")
	};
#pragma keylist command_disable_38d0a147 
struct command_enable_45c22764 {  // @Metadata=(Description="Transition from state Disabled to Enabled.")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	value; // @Metadata=(Units="unitless",Description="Not used")
	};
#pragma keylist command_enable_45c22764 
struct command_enterControl_c67345d8 {  // @Metadata=(Description="Transition from state Offline to Standby. Only "externally commandable" CSCs support this command; other CSCs start in Standby state and quit when they go to Offline.")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	value; // @Metadata=(Units="unitless",Description="Not used")
	};
#pragma keylist command_enterControl_c67345d8 
struct command_exitControl_58c3a7d1 {  // @Metadata=(Description="Transition from state Standby to Offline. For CSCs that are not "externally commandable" this makes the CSC quit.")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	value; // @Metadata=(Units="unitless",Description="Not used")
	};
#pragma keylist command_exitControl_58c3a7d1 
struct command_lsstBarraoblPiso01BarraoblChiller01_3172636b {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  float	lsstBarraoblPiso01BarraoblChiller_01BarraoblSetpointActivoLsst; // @Metadata=(Units="unitless",Description="Floor 01 - Chiller 01 - Setpoint Active LSST")
	  boolean	lsstBarraoblPiso01BarraoblChiller_01BarraoblComandoEncendidoLsst; // @Metadata=(Units="unitless",Description="Floor 01 - Chiller 01 - Command Started LSST")
	};
#pragma keylist command_lsstBarraoblPiso01BarraoblChiller01_3172636b 
struct command_lsstBarraoblPiso01BarraoblTccGuionP1GuionSalaGuionMaquinas_c4752bce {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	lsstBarraoblPiso01BarraoblVea_01BarraoblComandoEncendidoLsst; // @Metadata=(Units="unitless",Description="Floor 01 - VEA 01 - Command Started LSST")
	  boolean	lsstBarraoblPiso01BarraoblVin_01BarraoblComandoEncendidoLsst; // @Metadata=(Units="unitless",Description="Floor 01 - VIN 01 - Command Started LSST")
	  boolean	lsstBarraoblPiso01BarraoblVec_01BarraoblComandoEncendidoLsst; // @Metadata=(Units="unitless",Description="Floor 01 - VEC 01 - Command Started LSST")
	};
#pragma keylist command_lsstBarraoblPiso01BarraoblTccGuionP1GuionSalaGuionMaquinas_c4752bce 
struct command_lsstBarraoblPiso02BarraoblCrack01_08d9c76e {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  float	setpointHumidificadorLsst; // @Metadata=(Units="unitless",Description="Setpoint Humidifier LSST")
	  float	setpointDeshumidificadorLsst; // @Metadata=(Units="unitless",Description="Setpoint Dehumidifier LSST")
	  float	setPointCoolingLsst; // @Metadata=(Units="unitless",Description="Setpoint Cooling LSST")
	  float	setPointHeatingLsst; // @Metadata=(Units="unitless",Description="Setpoint Heating LSST")
	  boolean	comandoEncendidoLsst; // @Metadata=(Units="unitless",Description="Command Started LSST")
	};
#pragma keylist command_lsstBarraoblPiso02BarraoblCrack01_08d9c76e 
struct command_lsstBarraoblPiso02BarraoblFancoil01_8c4c7f1b {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  float	pcto_AperturaValvulaFrioLsst; // @Metadata=(Units="unitless",Description="% Opening Valve Cold LSST")
	  float	setpointCoolingDayLsst; // @Metadata=(Units="unitless",Description="Setpoint Cooling Day LSST")
	  float	setpointHeatingDayLsst; // @Metadata=(Units="unitless",Description="Setpoint Heating Day LSST")
	  float	setpointCoolingNightLsst; // @Metadata=(Units="unitless",Description="Setpoint Cooling Night LSST")
	  float	setpointHeatingNightLsst; // @Metadata=(Units="unitless",Description="Setpoint Heating Night LSST")
	  float	setpointTrabajoLsst; // @Metadata=(Units="unitless",Description="Setpoint Work LSST")
	  boolean	comandoEncendidoLsst; // @Metadata=(Units="unitless",Description="Command Started LSST")
	};
#pragma keylist command_lsstBarraoblPiso02BarraoblFancoil01_8c4c7f1b 
struct command_lsstBarraoblPiso04BarraoblManejadoraBarraoblSblanca_995ee053 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  float	valorConsignaLsst; // @Metadata=(Units="unitless",Description="Value Setpoint LSST")
	  float	setpointVentiladorMinLsst; // @Metadata=(Units="unitless",Description="Setpoint Fan Min LSST")
	  float	setpointVentiladorMaxLsst; // @Metadata=(Units="unitless",Description="Setpoint Fan Max LSST")
	  boolean	comandoEncendidoLsst; // @Metadata=(Units="unitless",Description="Command Started LSST")
	};
#pragma keylist command_lsstBarraoblPiso04BarraoblManejadoraBarraoblSblanca_995ee053 
struct command_lsstBarraoblPiso04BarraoblTccGuionP4GuionVex_26db6bb2 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	lsstBarraoblPiso04BarraoblVex_03BarraoblComandoEncendidoLsst; // @Metadata=(Units="unitless",Description="Floor 04 - VEX 03 - Command Started LSST")
	  boolean	lsstBarraoblPiso04BarraoblVex_04BarraoblComandoEncendidoLsst; // @Metadata=(Units="unitless",Description="Floor 04 - VEX 04 - Command Started LSST")
	};
#pragma keylist command_lsstBarraoblPiso04BarraoblTccGuionP4GuionVex_26db6bb2 
struct command_lsstBarraoblPiso05BarraoblManejadoraBarraoblLower_01_d4090a15 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  float	setpointTrabajoLsst; // @Metadata=(Units="unitless",Description="Setpoint Work LSST")
	  float	setpointVentiladorMinLsst; // @Metadata=(Units="unitless",Description="Setpoint Fan Min LSST")
	  float	setpointVentiladorMaxLsst; // @Metadata=(Units="unitless",Description="Setpoint Fan Max LSST")
	  float	temperaturaAnticongelanteLsst; // @Metadata=(Units="unitless",Description="Temperature Anti-freeze LSST")
	  boolean	comandoEncendidoLsst; // @Metadata=(Units="unitless",Description="Command Started LSST")
	};
#pragma keylist command_lsstBarraoblPiso05BarraoblManejadoraBarraoblLower_01_d4090a15 
struct command_lsstBarraoblPiso05BarraoblTccGuionP5GuionPir_93a33d08 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	lsstBarraoblPiso05BarraoblVea_01BarraoblComandoEncendidoLsst; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 01 - Command Started LSST")
	  boolean	lsstBarraoblPiso05BarraoblVea_08BarraoblComandoEncendidoLsst; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 08 - Command Started LSST")
	  boolean	lsstBarraoblPiso05BarraoblVea_09BarraoblComandoEncendidoLsst; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 09 - Command Started LSST")
	  boolean	lsstBarraoblPiso05BarraoblVea_10BarraoblComandoEncendidoLsst; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 10 - Command Started LSST")
	  boolean	lsstBarraoblPiso05BarraoblVea_11BarraoblComandoEncendidoLsst; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 11 - Command Started LSST")
	  boolean	lsstBarraoblPiso05BarraoblVea_12BarraoblComandoEncendidoLsst; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 12 - Command Started LSST")
	  boolean	lsstBarraoblPiso05BarraoblVea_13BarraoblComandoEncendidoLsst; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 13 - Command Started LSST")
	  boolean	lsstBarraoblPiso05BarraoblVea_14BarraoblComandoEncendidoLsst; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 14 - Command Started LSST")
	  boolean	lsstBarraoblPiso05BarraoblVea_15BarraoblComandoEncendidoLsst; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 15 - Command Started LSST")
	  boolean	lsstBarraoblPiso05BarraoblVea_16BarraoblComandoEncendidoLsst; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 16 - Command Started LSST")
	  boolean	lsstBarraoblPiso05BarraoblVea_17BarraoblComandoEncendidoLsst; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 17 - Command Started LSST")
	};
#pragma keylist command_lsstBarraoblPiso05BarraoblTccGuionP5GuionPir_93a33d08 
struct command_setLogLevel_3df9c86c {  // @Metadata=(Description="Set the logging level.")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  long	level; // @Metadata=(Units="unitless",Description="Logging level; as a Python logging level: error=40; warning=30; info=20; debug=10.")
	};
#pragma keylist command_setLogLevel_3df9c86c 
struct command_setSimulationMode_a81dfaf1 {  // @Metadata=(Description="Set the simulation mode.")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  long	mode; // @Metadata=(Units="unitless",Description="Desired simulation mode; 0 for normal operation (no simulation); other supported values are specific to each CSC.")
	};
#pragma keylist command_setSimulationMode_a81dfaf1 
struct command_setValue_2d25a3f0 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string<256>	parametersAndValues; // @Metadata=(Units="unitless",Description="List of parameters and their values as a Json string")
	};
#pragma keylist command_setValue_2d25a3f0 
struct command_standby_2af12edd {  // @Metadata=(Description="Transition from state Offline; Disabled or Fault to Standby.")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	value; // @Metadata=(Units="unitless",Description="Not used")
	};
#pragma keylist command_standby_2af12edd 
struct command_start_b4dcfd23 {  // @Metadata=(Description="Transition from state Standby to Disable; in a specified configuration.")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string<256>	settingsToApply; // @Metadata=(Units="unitless",Description="Name of the selected settings set")
	};
#pragma keylist command_start_b4dcfd23 
struct logevent_appliedSettingsMatchStart_0c8688e2 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	appliedSettingsMatchStartIsTrue; // @Metadata=(Units="unitless",Description="True when the configuration matches the start conditions")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_appliedSettingsMatchStart_0c8688e2 
struct logevent_detailedState_d6c3bc62 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  long	detailedState; // @Metadata=(Units="unitless",Description="Detailed state")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_detailedState_d6c3bc62 
	 const long HVAC_shared_SummaryState_DisabledState=1;
	 const long HVAC_shared_SummaryState_EnabledState=2;
	 const long HVAC_shared_SummaryState_FaultState=3;
	 const long HVAC_shared_SummaryState_OfflineState=4;
	 const long HVAC_shared_SummaryState_StandbyState=5;
	 const long HVAC_shared_DetailedState_DisabledState=1;
	 const long HVAC_shared_DetailedState_EnabledState=2;
	 const long HVAC_shared_DetailedState_FaultState=3;
	 const long HVAC_shared_DetailedState_OfflineState=4;
	 const long HVAC_shared_DetailedState_StandbyState=5;
struct logevent_errorCode_534acb5d {  // @Metadata=(Description="Output when a CSC goes into the Fault state as an explanation of the problem.")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  long	errorCode; // @Metadata=(Units="unitless",Description="A numeric error code")
	  string	errorReport; // @Metadata=(Units="unitless",Description="An string providing detailed information about the error")
	  string	traceback; // @Metadata=(Units="unitless",Description="An optional stack trace of the error condition")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_errorCode_534acb5d 
struct logevent_heartbeat_d8df0bff {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	heartbeat; // @Metadata=(Units="unitless",Description="Beats the drum.")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_heartbeat_d8df0bff 
struct logevent_logLevel_24d58d6c {  // @Metadata=(Description="Current logging level.")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  long	level; // @Metadata=(Units="unitless",Description="Current logging level; a Python logging level: error=40; warning=30; info=20; debug=10.")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_logLevel_24d58d6c 
struct logevent_logMessage_6d7fd001 {  // @Metadata=(Description="A log message.")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string	name; // @Metadata=(Units="unitless",Description="Log name.")
	  long	level; // @Metadata=(Units="unitless",Description="Message level; a Python logging level: error=40; warning=30; info=20; debug=10.")
	  string	message; // @Metadata=(Units="unitless",Description="Log message.")
	  string	traceback; // @Metadata=(Units="unitless",Description="Exception traceback; "" if not an exception.")
	  string	filePath; // @Metadata=(Units="unitless",Description="Path to source file.")
	  string	functionName; // @Metadata=(Units="unitless",Description="Function or method name.")
	  long	lineNumber; // @Metadata=(Units="unitless",Description="Line number in the file specified by filePath.")
	  long	process; // @Metadata=(Units="unitless",Description="Process ID.")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_logMessage_6d7fd001 
struct logevent_settingVersions_6d1ef24a {  // @Metadata=(Description="Information about settings which can be specified in the start command.")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string	recommendedSettingsVersion; // @Metadata=(Units="unitless",Description="List of comma seperated recomended versions of settings sets")
	  string	recommendedSettingsLabels; // @Metadata=(Units="unitless",Description="List of comma seperated names of settings sets")
	  string	settingsUrl; // @Metadata=(Units="unitless",Description="The URL where the settings sets definitions can be found")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_settingVersions_6d1ef24a 
struct logevent_settingsApplied_9df389ff {  // @Metadata=(Description="Base settings applied.")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string<256>	settingsVersion; // @Metadata=(Units="unitless",Description="The SHA or name corresponding to the published configuration")
	  string	otherSettingsEvents; // @Metadata=(Units="unitless",Description="A comma delimited list of other specific CSC configuration events. This may be blank if no other CSC specific events are necessary")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_settingsApplied_9df389ff 
struct logevent_simulationMode_f7652126 {  // @Metadata=(Description="Current simulation mode.")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  long	mode; // @Metadata=(Units="unitless",Description="Current simulation mode; 0 for normal operation (no simulation); other supported values are specific to each CSC.")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_simulationMode_f7652126 
struct logevent_softwareVersions_424fb55c {  // @Metadata=(Description="Current verions of software in use by CSC.")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  string<16>	salVersion; // @Metadata=(Units="unitless",Description="This is the current version of SAL generation")
	  string<16>	xmlVersion; // @Metadata=(Units="unitless",Description="This is the current version of CSC XML")
	  string<16>	openSpliceVersion; // @Metadata=(Units="unitless",Description="This is the current version of OpenSplice")
	  string<16>	cscVersion; // @Metadata=(Units="unitless",Description="This is the top-level version of the CSC")
	  string	subsystemVersions; // @Metadata=(Units="unitless",Description="A comma delimited list of key=value pairs relating subsystem name (key) to its version number (value). This may be left blank if there are no subsystems within a CSC")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_softwareVersions_424fb55c 
struct logevent_summaryState_a76ac404 {  // @Metadata=(Description="Current summary state of the CSC")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  long	summaryState; // @Metadata=(Units="unitless",Description="High level state machine state identifier")
	  long	priority; // @Metadata=(Units="unitless",Description="Priority code")
	};
#pragma keylist logevent_summaryState_a76ac404 
struct lsstBarraoblPiso01BarraoblChiller01_4f49f161 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  float	lsstBarraoblPiso01BarraoblChiller_01BarraoblTemperaturaAguaRetornoEvaporador; // @Metadata=(Units="unitless",Description="Floor 01 - Chiller 01 - Temperature Water Return Evaparator")
	  float	lsstBarraoblPiso01BarraoblChiller_01BarraoblTemperaturaAguaImpulsionEvaporador; // @Metadata=(Units="unitless",Description="Floor 01 - Chiller 01 - Temperature Water Impulse Evaparator")
	  float	lsstBarraoblPiso01BarraoblChiller_01BarraoblPresionBajaCto1; // @Metadata=(Units="unitless",Description="Floor 01 - Chiller 01 - Pressure Low CTO1")
	  float	lsstBarraoblPiso01BarraoblChiller_01BarraoblPresionBajaCto2; // @Metadata=(Units="unitless",Description="Floor 01 - Chiller 01 - Pressure Low CTO2")
	  boolean	lsstBarraoblPiso01BarraoblChiller_01BarraoblComandoEncendido; // @Metadata=(Units="unitless",Description="Floor 01 - Chiller 01 - Command Started")
	  float	lsstBarraoblPiso01BarraoblChiller_01BarraoblPotenciaDisponibleChiller; // @Metadata=(Units="unitless",Description="Floor 01 - Chiller 01 - Power Available Chiller")
	  float	lsstBarraoblPiso01BarraoblChiller_01Barraobl_PctoPotenciaTrabajo; // @Metadata=(Units="unitless",Description="Floor 01 - Chiller 01 - %Power Work")
	  float	lsstBarraoblPiso01BarraoblChiller_01BarraoblEstadoFuncionamiento; // @Metadata=(Units="unitless",Description="Floor 01 - Chiller 01 - State Working")
	  float	lsstBarraoblPiso01BarraoblChiller_01BarraoblModoOperacion; // @Metadata=(Units="unitless",Description="Floor 01 - Chiller 01 - Mode Operation")
	  float	lsstBarraoblPiso01BarraoblChiller_01BarraoblEstadoUnidad; // @Metadata=(Units="unitless",Description="Floor 01 - Chiller 01 - State Unit")
	  float	lsstBarraoblPiso01BarraoblChiller_01BarraoblHorasCompresorPromedio; // @Metadata=(Units="unitless",Description="Floor 01 - Chiller 01 - Hours Compressor Mean")
	  float	lsstBarraoblPiso01BarraoblChiller_01BarraoblHorasCompresor_01; // @Metadata=(Units="unitless",Description="Floor 01 - Chiller 01 - Hours Compressor 01")
	  float	lsstBarraoblPiso01BarraoblChiller_01BarraoblHorasCompresor_02; // @Metadata=(Units="unitless",Description="Floor 01 - Chiller 01 - Hours Compressor 02")
	  float	lsstBarraoblPiso01BarraoblChiller_01BarraoblHorasCompresor_03; // @Metadata=(Units="unitless",Description="Floor 01 - Chiller 01 - Hours Compressor 03")
	  float	lsstBarraoblPiso01BarraoblChiller_01BarraoblHorasCompresor_04; // @Metadata=(Units="unitless",Description="Floor 01 - Chiller 01 - Hours Compressor 04")
	  boolean	lsstBarraoblPiso01BarraoblChiller_01BarraoblCompresor_01Funcionando; // @Metadata=(Units="unitless",Description="Floor 01 - Chiller 01 - Compressor 01 Functioning")
	  boolean	lsstBarraoblPiso01BarraoblChiller_01BarraoblCompresor_02Funcionando; // @Metadata=(Units="unitless",Description="Floor 01 - Chiller 01 - Compressor 02 Functioning")
	  boolean	lsstBarraoblPiso01BarraoblChiller_01BarraoblCompresor_03Funcionando; // @Metadata=(Units="unitless",Description="Floor 01 - Chiller 01 - Compressor 03 Functioning")
	  boolean	lsstBarraoblPiso01BarraoblChiller_01BarraoblCompresor_04Funcionando; // @Metadata=(Units="unitless",Description="Floor 01 - Chiller 01 - Compressor 04 Functioning")
	  float	lsstBarraoblPiso01BarraoblChiller_01BarraoblCompresor_01Alarmado; // @Metadata=(Units="unitless",Description="Floor 01 - Chiller 01 - Compressor 01 Alarm DO")
	  float	lsstBarraoblPiso01BarraoblChiller_01BarraoblCompresor_02Alarmado; // @Metadata=(Units="unitless",Description="Floor 01 - Chiller 01 - Compressor 02 Alarm DO")
	  float	lsstBarraoblPiso01BarraoblChiller_01BarraoblCompresor_03Alarmado; // @Metadata=(Units="unitless",Description="Floor 01 - Chiller 01 - Compressor 03 Alarm DO")
	  float	lsstBarraoblPiso01BarraoblChiller_01BarraoblCompresor_04Alarmado; // @Metadata=(Units="unitless",Description="Floor 01 - Chiller 01 - Compressor 04 Alarm DO")
	  float	lsstBarraoblPiso01BarraoblChiller_01BarraoblAlarmaGeneral; // @Metadata=(Units="unitless",Description="Floor 01 - Chiller 01 - Alarm General")
	};
#pragma keylist lsstBarraoblPiso01BarraoblChiller01_4f49f161 
struct lsstBarraoblPiso01BarraoblTccGuionP1GuionSalaGuionMaquinas_506926a8 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	lsstBarraoblPiso01BarraoblVin_01BarraoblEstadoFuncionamiento; // @Metadata=(Units="unitless",Description="Floor 01 - VIN 01 - State Working")
	  boolean	lsstBarraoblPiso01BarraoblVec_01BarraoblEstadoFuncionamiento; // @Metadata=(Units="unitless",Description="Floor 01 - VEC 01 - State Working")
	  boolean	lsstBarraoblPiso01BarraoblBombaAguaFriaBarraoblEstadoFuncionamiento; // @Metadata=(Units="unitless",Description="Floor 01 - Pump Water Cold - State Working")
	  boolean	lsstBarraoblPiso01BarraoblVea_01BarraoblEstadoSelector; // @Metadata=(Units="unitless",Description="Floor 01 - VEA 01 - State Switch")
	  boolean	lsstBarraoblPiso01BarraoblVin_01BarraoblEstadoSelector; // @Metadata=(Units="unitless",Description="Floor 01 - VIN 01 - State Switch")
	  boolean	lsstBarraoblPiso01BarraoblVec_01BarraoblEstadoSelector; // @Metadata=(Units="unitless",Description="Floor 01 - VEC 01 - State Switch")
	  boolean	lsstBarraoblPiso01BarraoblVea_01BarraoblComandoEncendido; // @Metadata=(Units="unitless",Description="Floor 01 - VEA 01 - Command Started")
	  boolean	lsstBarraoblPiso01BarraoblVin_01BarraoblComandoEncendido; // @Metadata=(Units="unitless",Description="Floor 01 - VIN 01 - Command Started")
	  boolean	lsstBarraoblPiso01BarraoblVec_01BarraoblComandoEncendido; // @Metadata=(Units="unitless",Description="Floor 01 - VEC 01 - Command Started")
	  boolean	lsstBarraoblPiso01BarraoblValvulaBarraoblEstadoValvula_1Amper_2; // @Metadata=(Units="unitless",Description="Floor 01 - Valve - State Valve 1 and 2")
	  boolean	lsstBarraoblPiso01BarraoblBombaAguaFriaBarraoblComandoEncendido; // @Metadata=(Units="unitless",Description="Floor 01 - Pump Water Cold - Command Started")
	  float	lsstBarraoblPiso01BarraoblTemperaturaAmbiente; // @Metadata=(Units="unitless",Description="Floor 01 - Temperature Ambient")
	  boolean	lsstBarraoblPiso01BarraoblValvulaBarraoblEstadoValvula_03; // @Metadata=(Units="unitless",Description="Floor 01 - Valve - State Valve 03")
	  boolean	lsstBarraoblPiso01BarraoblValvulaBarraoblEstadoValvula_04; // @Metadata=(Units="unitless",Description="Floor 01 - Valve - State Valve 04")
	  boolean	lsstBarraoblPiso01BarraoblValvulaBarraoblEstadoValvula_05; // @Metadata=(Units="unitless",Description="Floor 01 - Valve - State Valve 05")
	  boolean	lsstBarraoblPiso01BarraoblValvulaBarraoblEstadoValvula_06; // @Metadata=(Units="unitless",Description="Floor 01 - Valve - State Valve 06")
	};
#pragma keylist lsstBarraoblPiso01BarraoblTccGuionP1GuionSalaGuionMaquinas_506926a8 
struct lsstBarraoblPiso02BarraoblCrack01_6cdda623 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  float	temperaturaRetorno; // @Metadata=(Units="unitless",Description="Temperature Return")
	  float	pctoHumedadSala; // @Metadata=(Units="unitless",Description="%Humidity Room")
	  float	setpointHumidificador; // @Metadata=(Units="unitless",Description="Setpoint Humidifier")
	  float	setpointDeshumidificador; // @Metadata=(Units="unitless",Description="Setpoint Dehumidifier")
	  float	setPointCooling; // @Metadata=(Units="unitless",Description="Setpoint Cooling")
	  float	setPointHeating; // @Metadata=(Units="unitless",Description="Setpoint Heating")
	  float	pctoAperturaValvula; // @Metadata=(Units="unitless",Description="%Opening Valve")
	  float	requerimientoHumificador; // @Metadata=(Units="unitless",Description="Requirement Humidifier")
	  boolean	estadoFuncionamiento; // @Metadata=(Units="unitless",Description="State Working")
	  float	estadoEspacioDeEspacioUnidad; // @Metadata=(Units="unitless",Description="State Of Unit")
	  float	modoOperacionUnidad; // @Metadata=(Units="unitless",Description="Mode Operation Unit")
	  boolean	estadoPresenciaAlarma; // @Metadata=(Units="unitless",Description="State Presense Alarm")
	  float	numeroCircuitos; // @Metadata=(Units="unitless",Description="Number Circuits")
	  boolean	comandoEncendido; // @Metadata=(Units="unitless",Description="Command Started")
	};
#pragma keylist lsstBarraoblPiso02BarraoblCrack01_6cdda623 
struct lsstBarraoblPiso02BarraoblFancoil01_0fcea487 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	estadoOperacion; // @Metadata=(Units="unitless",Description="State Operation")
	  boolean	estadoCalefactor; // @Metadata=(Units="unitless",Description="State Heater")
	  boolean	estadoVentilador; // @Metadata=(Units="unitless",Description="State Fan")
	  float	pcto_AperturaValvulaFrio; // @Metadata=(Units="unitless",Description="% Opening Valve Cold")
	  float	setpointCoolingDay; // @Metadata=(Units="unitless",Description="Setpoint Cooling Day")
	  float	setpointHeatingDay; // @Metadata=(Units="unitless",Description="Setpoint Heating Day")
	  float	setpointCoolingNight; // @Metadata=(Units="unitless",Description="Setpoint Cooling Night")
	  float	setpointHeatingNight; // @Metadata=(Units="unitless",Description="Setpoint Heating Night")
	  float	setpointTrabajo; // @Metadata=(Units="unitless",Description="Setpoint Work")
	  boolean	comandoEncendido; // @Metadata=(Units="unitless",Description="Command Started")
	};
#pragma keylist lsstBarraoblPiso02BarraoblFancoil01_0fcea487 
struct lsstBarraoblPiso04BarraoblManejadoraBarraoblSblanca_0938a1c5 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	estadoFuncionamiento; // @Metadata=(Units="unitless",Description="State Working")
	  float	lsstBarraoblPiso04BarraoblManejadraBarraoblSblancaBarraoblEstadoTemperaturaAmbiente; // @Metadata=(Units="unitless",Description="Floor 04 - Manager - White Room - State Temperature Ambient")
	  float	estadoTemperaturaExterior; // @Metadata=(Units="unitless",Description="State Temperature Exterior")
	  float	estadoTemperaturaAnticongelante; // @Metadata=(Units="unitless",Description="State Temperature Anti-freeze")
	  float	valorConsigna; // @Metadata=(Units="unitless",Description="Value Setpoint")
	  float	setpointTrabajo; // @Metadata=(Units="unitless",Description="Setpoint Work")
	  float	temperaturaInyeccion; // @Metadata=(Units="unitless",Description="Temperature Injection")
	  float	temperaturaRetorno; // @Metadata=(Units="unitless",Description="Temperature Return")
	  boolean	alarmaGeneral; // @Metadata=(Units="unitless",Description="Alarm General")
	  boolean	alarmaFiltro; // @Metadata=(Units="unitless",Description="Alarm Filter")
	  boolean	resetAlarma; // @Metadata=(Units="unitless",Description="Reset Alarm")
	  boolean	estadoValvula; // @Metadata=(Units="unitless",Description="State Valve")
	  boolean	calefaccionEtapa_01; // @Metadata=(Units="unitless",Description="Heating Stage 01")
	  boolean	calefaccionEtapa_02; // @Metadata=(Units="unitless",Description="Heating Stage 02")
	  float	caudalVentiladorImpulsion; // @Metadata=(Units="unitless",Description="Yield Fan Impulse")
	  float	setpointVentiladorMin; // @Metadata=(Units="unitless",Description="Setpoint Fan Min")
	  float	setpointVentiladorMax; // @Metadata=(Units="unitless",Description="Setpoint Fan Max")
	  boolean	comandoEncendido; // @Metadata=(Units="unitless",Description="Command Started")
	};
#pragma keylist lsstBarraoblPiso04BarraoblManejadoraBarraoblSblanca_0938a1c5 
struct lsstBarraoblPiso04BarraoblManejadoraBarraoblSlimpia_db0593ef {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  float	lsstBarraoblPiso04BarraoblManejadoraBarraoblSblancaBarraoblTemperaturaSala; // @Metadata=(Units="unitless",Description="Floor 04 - Manager - White Room - Temperature Room")
	};
#pragma keylist lsstBarraoblPiso04BarraoblManejadoraBarraoblSlimpia_db0593ef 
struct lsstBarraoblPiso04BarraoblTccGuionP4GuionVex_27bc4976 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	lsstBarraoblPiso04BarraoblVea_04BarraoblEstadoFuncionamiento; // @Metadata=(Units="unitless",Description="Floor 04 - VEA 04 - State Working")
	  boolean	lsstBarraoblPiso04BarraoblVex_03BarraoblFallaTermica; // @Metadata=(Units="unitless",Description="Floor 04 - VEX 03 - Error Thermal")
	  boolean	lsstBarraoblPiso04BarraoblVex_04BarraoblFallaTermica; // @Metadata=(Units="unitless",Description="Floor 04 - VEX 04 - Error Thermal")
	  boolean	lsstBarraoblPiso04BarraoblVex_03BarraoblComandoEncendido; // @Metadata=(Units="unitless",Description="Floor 04 - VEX 03 - Command Started")
	  boolean	lsstBarraoblPiso04BarraoblVex_04BarraoblComandoEncendido; // @Metadata=(Units="unitless",Description="Floor 04 - VEX 04 - Command Started")
	  boolean	lsstBarraoblPiso04BarraoblDamperLowerBarraoblComando; // @Metadata=(Units="unitless",Description="Floor 04 - Damper Lower - Command")
	  boolean	lsstBarraoblPiso04BarraoblZonaCargacomandoEncendido; // @Metadata=(Units="unitless",Description="Floor 04 - Zone Loading Command Started")
	};
#pragma keylist lsstBarraoblPiso04BarraoblTccGuionP4GuionVex_27bc4976 
struct lsstBarraoblPiso05BarraoblManejadoraBarraoblLower_01_a6c28279 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  float	setpointTrabajo; // @Metadata=(Units="unitless",Description="Setpoint Work")
	  float	setpointVentiladorMin; // @Metadata=(Units="unitless",Description="Setpoint Fan Min")
	  float	setpointVentiladorMax; // @Metadata=(Units="unitless",Description="Setpoint Fan Max")
	  float	setPointVentImpulsion; // @Metadata=(Units="unitless",Description="Setpoint Vent Impulse")
	  float	temperaturaAnticongelante; // @Metadata=(Units="unitless",Description="Temperature Anti-freeze")
	  float	temperaturaInyeccion; // @Metadata=(Units="unitless",Description="Temperature Injection")
	  float	temperaturaRetorno; // @Metadata=(Units="unitless",Description="Temperature Return")
	  boolean	alarmaGeneral; // @Metadata=(Units="unitless",Description="Alarm General")
	  boolean	alarmaFiltro; // @Metadata=(Units="unitless",Description="Alarm Filter")
	  boolean	estadoFuncionamiento; // @Metadata=(Units="unitless",Description="State Working")
	  boolean	estadoDamper; // @Metadata=(Units="unitless",Description="State Damper")
	  boolean	resetAlarma; // @Metadata=(Units="unitless",Description="Reset Alarm")
	  boolean	temperaturaAmbienteAmperExterior; // @Metadata=(Units="unitless",Description="Temperature Ambient and Exterior")
	  boolean	estadoValvula; // @Metadata=(Units="unitless",Description="State Valve")
	  boolean	caudalVentiladorImpulsion; // @Metadata=(Units="unitless",Description="Yield Fan Impulse")
	  boolean	comandoEncendido; // @Metadata=(Units="unitless",Description="Command Started")
	};
#pragma keylist lsstBarraoblPiso05BarraoblManejadoraBarraoblLower_01_a6c28279 
struct lsstBarraoblPiso05BarraoblTccGuionP5GuionPir_8b60bdb8 {  // @Metadata=(Description="")
	  string<8>	private_revCode; //private // @Metadata=(Units="unitless",Description="Revision code of topic")
	  double	private_sndStamp; //private // @Metadata=(Units="second",Description="TAI at sender")
	  double	private_rcvStamp; //private // @Metadata=(Units="second",Description="TAI at receiver")
	  long		private_seqNum; //private // @Metadata=(Units="unitless",Description="Sequence number")
	  long		private_origin; //private // @Metadata=(Units="unitless",Description="PID code of sender")
	  long		private_host; //private // @Metadata=(Units="unitless",Description="IP of sender")
	  boolean	lsstBarraoblPiso05BarraoblVea_08BarraoblEstadoFuncionamiento; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 08 - State Working")
	  boolean	lsstBarraoblPiso05BarraoblVea_09BarraoblEstadoFuncionamiento; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 09 - State Working")
	  boolean	lsstBarraoblPiso05BarraoblVea_10BarraoblEstadoFuncionamiento; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 10 - State Working")
	  boolean	lsstBarraoblPiso05BarraoblVea_11BarraoblEstadoFuncionamiento; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 11 - State Working")
	  boolean	lsstBarraoblPiso05BarraoblVea_12BarraoblEstadoFuncionamiento; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 12 - State Working")
	  boolean	lsstBarraoblPiso05BarraoblVea_13BarraoblEstadoFuncionamiento; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 13 - State Working")
	  boolean	lsstBarraoblPiso05BarraoblVea_14BarraoblEstadoFuncionamiento; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 14 - State Working")
	  boolean	lsstBarraoblPiso05BarraoblVea_15BarraoblEstadoFuncionamiento; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 15 - State Working")
	  boolean	lsstBarraoblPiso05BarraoblVea_16BarraoblEstadoFuncionamiento; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 16 - State Working")
	  boolean	lsstBarraoblPiso05BarraoblVea_17BarraoblEstadoFuncionamiento; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 17 - State Working")
	  boolean	lsstBarraoblPiso05BarraoblVea_01BarraoblFallaTermica; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 01 - Error Thermal")
	  boolean	lsstBarraoblPiso05BarraoblVea_08BarraoblFallaTermica; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 08 - Error Thermal")
	  boolean	lsstBarraoblPiso05BarraoblVea_09BarraoblFallaTermica; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 09 - Error Thermal")
	  boolean	lsstBarraoblPiso05BarraoblVea_10BarraoblFallaTermica; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 10 - Error Thermal")
	  boolean	lsstBarraoblPiso05BarraoblVea_11BarraoblFallaTermica; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 11 - Error Thermal")
	  boolean	lsstBarraoblPiso05BarraoblVea_12BarraoblFallaTermica; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 12 - Error Thermal")
	  boolean	lsstBarraoblPiso05BarraoblVea_13BarraoblFallaTermica; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 13 - Error Thermal")
	  boolean	lsstBarraoblPiso05BarraoblVea_14BarraoblFallaTermica; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 14 - Error Thermal")
	  boolean	lsstBarraoblPiso05BarraoblVea_15BarraoblFallaTermica; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 15 - Error Thermal")
	  boolean	lsstBarraoblPiso05BarraoblVea_16BarraoblFallaTermica; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 16 - Error Thermal")
	  boolean	lsstBarraoblPiso05BarraoblVea_17BarraoblFallaTermica; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 17 - Error Thermal")
	  boolean	lsstBarraoblPiso05BarraoblVea_01BarraoblComandoEncendido; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 01 - Command Started")
	  boolean	lsstBarraoblPiso05BarraoblVea_08BarraoblComandoEncendido; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 08 - Command Started")
	  boolean	lsstBarraoblPiso05BarraoblVea_09BarraoblComandoEncendido; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 09 - Command Started")
	  boolean	lsstBarraoblPiso05BarraoblVea_10BarraoblComandoEncendido; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 10 - Command Started")
	  boolean	lsstBarraoblPiso05BarraoblVea_11BarraoblComandoEncendido; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 11 - Command Started")
	  boolean	lsstBarraoblPiso05BarraoblVea_12BarraoblComandoEncendido; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 12 - Command Started")
	  boolean	lsstBarraoblPiso05BarraoblVea_13BarraoblComandoEncendido; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 13 - Command Started")
	  boolean	lsstBarraoblPiso05BarraoblVea_14BarraoblComandoEncendido; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 14 - Command Started")
	  boolean	lsstBarraoblPiso05BarraoblVea_15BarraoblComandoEncendido; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 15 - Command Started")
	  boolean	lsstBarraoblPiso05BarraoblVea_16BarraoblComandoEncendido; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 16 - Command Started")
	  boolean	lsstBarraoblPiso05BarraoblVea_17BarraoblComandoEncendido; // @Metadata=(Units="unitless",Description="Floor 05 - VEA 17 - Command Started")
	};
#pragma keylist lsstBarraoblPiso05BarraoblTccGuionP5GuionPir_8b60bdb8 
struct ackcmd_3bc1859e {  // @Metadata=(Description="")
      string<8>	private_revCode;
      double		private_sndStamp;
      double		private_rcvStamp;
      long		private_origin;
      long 		private_host;
      long		private_seqNum;
      long 		ack;
      long 		error;
      string<256>	result;
      long		host;
      long		origin;
      long		cmdtype;
      double		timeout;
	};
#pragma keylist ackcmd_3bc1859e 
};

